@@ -20,6 +20,7 @@ our %servers = qw(
 
     XN--80ASWG          whois.site.rs.corenic.net
     XN--80ASEHDB        whois.online.rs.corenic.net
+    XN--80ADXHKS        whois.nic.xn--80adxhks
 
     COM.RU              whois.nic.ru
     NET.RU              whois.nic.ru
@@ -309,6 +310,7 @@ our %servers = qw(
 
     CLUB            whois.nic.club
     LUXURY          whois.nic.luxury
+    WIEN            whois.nic.wien
 
     ACTOR           whois.unitedtld.com
     AIRFORCE        whois.unitedtld.com
@@ -791,6 +793,7 @@ our %notfound = (
     'whois.nic.club'             => '^Not found:',
     'whois.unitedtld.com'        => 'Domain not found',
     'whois.nic.luxury'           => 'No Data Found',
+    'whois.nic.wien'             => 'No match',
 
     'whois.publicinterestregistry.net' => 'NOT FOUND',
     'whois-dub.mm-registry.com'        => 'Status: Not Registered',
@@ -957,6 +960,7 @@ our %notfound = (
 
     'whois.online.rs.corenic.net' => 'no matching objects found',
     'whois.site.rs.corenic.net'   => 'no matching objects found',
+    'whois.nic.xn--80adxhks'      => 'No entries found for the selected source',
 );
 
 # Common whois stripping REs
@@ -986,6 +990,9 @@ our %strip = (
     'whois.nic.berlin' => [
         '^%',
     ],
+    'whois.nic.wien' => [
+        '^%',
+    ],
 
     'whois-dub.mm-registry.com' => [
         '^[^A-Z]',
@@ -2470,12 +2477,9 @@ our %strip = (
         '^the right to modify these terms at any time. By submitting this query,',
         '^you agree to abide by this policy.',
     ],
-    'whois.online.rs.corenic.net' => [
-        '^%',
-    ],
-    'whois.site.rs.corenic.net' => [
-        '^%',
-    ],
+    'whois.online.rs.corenic.net' => [ '^%' ],
+    'whois.site.rs.corenic.net'   => [ '^%' ],
+    'whois.nic.xn--80adxhks'      => [ '^%' ],
 );
 
 our %exceed = (
